package com.ruoyi.post.service;

import com.ruoyi.post.domain.PostNews;
import com.ruoyi.post.domain.PostNews;

import java.util.List;

/**
 * @Author HuiANan
 * @Date 2023/1/17 20:48
 * @Exegesis:
 */
public interface IPostNewsService
{
    /**
     * 查询通知消息管理;
     *
     * @param newsId 通知消息管理;
     * @return 通知消息管理;
     */
    public PostNews selectPostNewsByNewsId(Integer newsId);

    /**
     * 查询通知消息管理;
     *
     * @param postNews 通知消息管理;
     * @return 通知消息管理;
     */
    public List<PostNews> selectPostNewsList(PostNews postNews);

    /**
     * 新增通知消息管理;
     *
     * @param postNews 通知消息管理;
     * @return 结果
     */
    public int insertPostNews(PostNews postNews);

    /**
     * 修改通知消息管理;
     *
     * @param postNews 通知消息管理;
     * @return 结果
     */
    public int updatePostNews(PostNews postNews);

    /**
     * 批量删除通知消息管理;
     *
     * @param newsIds 需要删除的通知消息管理;
     * @return 结果
     */
    public int deletePostNewsByNewsIds(Integer[] newsIds);

    /**
     * 删除通知消息管理;
     *
     * @param newsId 通知消息管理;
     * @return 结果
     */
    public int deletePostNewsByNewsId(Integer newsId);

    /**
     * 查看详情
     */
    public PostNews selectViewDetail(Integer newsId);

    /**
     * 判断消息标题是否唯一
     */
    public String checkTitle(PostNews postNews);

    /**
     * 查看详情
     */
    public String checkContent(PostNews postNews);

    /**
     *
     * @param phoneList 手机号码列表
     * @param isUpdateSupport
     * @param operName
     * @return
     */
    public String importPhone(List<PostNews> phoneList, Boolean isUpdateSupport, String operName,PostNews postNews);

    /**
     * 新增消息电话增加
     * @param postNews
     * @return
     */
    public int insertBulletin(PostNews postNews);
}